@@ -1,9 +1,17 @@
 /*
- * Copyright (C) 2004-2012  See the AUTHORS file for details.
+ * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 as published
- * by the Free Software Foundation.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 #ifndef _MODULES_H
@@ -756,6 +764,19 @@ public:
 	 */
 	virtual EModRet OnTimerAutoJoin(CChan& Channel);
 
+	/** This module hook is called when a network is being added.
+	 *  @param Network The new IRC network.
+	 *  @param sErrorRet A message that may be displayed to the user if
+	 *                  the module stops adding the network.
+	 *  @return See CModule::EModRet.
+	 */
+	virtual EModRet OnAddNetwork(CIRCNetwork& Network, CString& sErrorRet);
+	/** This module hook is called when a network is deleted.
+	 *  @param Network The IRC network which is going to be deleted.
+	 *  @return See CModule::EModRet.
+	 */
+	virtual EModRet OnDeleteNetwork(CIRCNetwork& Network);
+
 	ModHandle GetDLL() { return m_pDLL; }
 	static double GetCoreVersion() { return VERSION; }
 
@@ -875,6 +896,8 @@ public:
 	bool ClearNV(bool bWriteToDisk = true);
 
 	const CString& GetSavePath() const;
+	CString ExpandString(const CString& sStr) const;
+	CString& ExpandString(const CString& sStr, CString& sRet) const;
 
 	// Setters
 	void SetType(CModInfo::EModuleType eType) { m_eType = eType; }
@@ -1095,6 +1118,9 @@ public:
 	bool OnTopic(CNick& Nick, CChan& Channel, CString& sTopic);
 	bool OnTimerAutoJoin(CChan& Channel);
 
+	bool OnAddNetwork(CIRCNetwork& Network, CString& sErrorRet);
+	bool OnDeleteNetwork(CIRCNetwork& Network);
+
 	bool OnServerCapAvailable(const CString& sCap);
 	bool OnServerCapResult(const CString& sCap, bool bSuccess);
 
