@@ -1,16 +1,24 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 as published
- * by the Free Software Foundation.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 #ifndef _UTILS_H
 #define _UTILS_H
 
-#include "zncconfig.h"
-#include "ZNCString.h"
+#include <znc/zncconfig.h>
+#include <znc/ZNCString.h>
 #include <assert.h>
 #include <cstdio>
 #include <fcntl.h>
@@ -20,10 +28,6 @@
 #include <unistd.h>
 #include <vector>
 
-using std::map;
-using std::vector;
-using std::pair;
-
 static inline void SetFdCloseOnExec(int fd)
 {
 	int flags = fcntl(fd, F_GETFD, 0);
@@ -49,7 +53,10 @@ public:
 	static void PrintAction(const CString& sMessage);
 	static void PrintStatus(bool bSuccess, const CString& sMessage = "");
 
+#ifndef SWIGPERL
+	// TODO refactor this
 	static const CString sDefaultHash;
+#endif
 
 	static CString GetSaltedHashPass(CString& sSalt);
 	static CString GetSalt();
@@ -73,6 +80,10 @@ public:
 	static void GenerateCert(FILE *pOut, const CString& sHost = "");
 #endif /* HAVE_LIBSSL */
 
+	static CString CTime(time_t t, const CString& sTZ);
+	static CString FormatTime(time_t t, const CString& sFormat, const CString& sTZ);
+	static SCString GetTimezones();
+
 private:
 protected:
 };
@@ -121,7 +132,7 @@ protected:
 | hello | world |
 +-------+-------+@endverbatim
  */
-class CTable : protected vector<vector<CString> > {
+class CTable : protected std::vector<std::vector<CString> > {
 public:
 	CTable() {}
 	virtual ~CTable() {}
@@ -138,7 +149,7 @@ public:
 	 *  After calling this you can fill the row with content.
 	 *  @return The index of this row
 	 */
-	unsigned int AddRow();
+	size_type AddRow();
 
 	/** Sets a given cell in the table to a value.
 	 *  @param sColumn The name of the column you want to fill.
@@ -147,7 +158,7 @@ public:
 	 *                 If this is not given, the last row will be used.
 	 *  @return True if setting the cell was successful.
 	 */
-	bool SetCell(const CString& sColumn, const CString& sValue, unsigned int uRowIdx = ~0);
+	bool SetCell(const CString& sColumn, const CString& sValue, size_type uRowIdx = ~0);
 
 	/** Get a line of the table's output
 	 *  @param uIdx The index of the line you want.
@@ -162,26 +173,27 @@ public:
 	 *  @param uIdx The index of the column you are interested in.
 	 *  @return The width of the column.
 	 */
-	unsigned int GetColumnWidth(unsigned int uIdx) const;
+	CString::size_type GetColumnWidth(unsigned int uIdx) const;
 
 	/// Completely clear the table.
 	void Clear();
 
 	/// @return The number of rows in this table, not counting the header.
-	using vector<vector<CString> >::size;
+	using std::vector<std::vector<CString> >::size;
 
 	/// @return True if this table doesn't contain any rows.
-	using vector<vector<CString> >::empty;
+	using std::vector<std::vector<CString> >::empty;
 private:
 	unsigned int GetColumnIndex(const CString& sName) const;
 
 protected:
-	vector<CString>            m_vsHeaders;
-	map<CString, unsigned int> m_msuWidths;  // Used to cache the width of a column
+	std::vector<CString>            m_vsHeaders;
+	std::map<CString, CString::size_type> m_msuWidths;  // Used to cache the width of a column
 };
 
 
 #ifdef HAVE_LIBSSL
+#include <openssl/aes.h>
 #include <openssl/blowfish.h>
 #include <openssl/md5.h>
 //! does Blowfish w/64 bit feedback, no padding
@@ -300,7 +312,7 @@ public:
 	 * @return true if item existed and was removed, false if it never existed
 	 */
 	bool RemItem(const K& Item) {
-		return m_mItems.erase(Item);
+		return (m_mItems.erase(Item) != 0);
 	}
 
 	/**
@@ -332,10 +344,10 @@ public:
 	unsigned int GetTTL() const { return m_uTTL; }
 	// !Getters
 protected:
-	typedef pair<unsigned long long, V> value;
-	typedef typename map<K, value>::iterator iterator;
-	map<K, value>   m_mItems;   //!< Map of cached items.  The value portion of the map is for the expire time
-	unsigned int    m_uTTL;     //!< Default time-to-live duration
+	typedef std::pair<unsigned long long, V> value;
+	typedef typename std::map<K, value>::iterator iterator;
+	std::map<K, value>   m_mItems;   //!< Map of cached items.  The value portion of the map is for the expire time
+	unsigned int         m_uTTL;     //!< Default time-to-live duration
 };
 
 /**
